:mod:`euphorie.client.login`
==============================

.. automodule:: euphorie.client.login


Views
-----

.. autoclass:: Login
   :members:

.. autoclass:: LoginForm
   :members:

.. autoclass:: Tryout
   :members:

.. autoclass:: CreateTestSession
   :members:

.. autoclass:: Reminder
   :members:

.. autoclass:: Register
   :members:

.. autoclass:: Logout
   :members:
